@@ -6,11 +6,13 @@
 
 #include "korobov.h"
 #include "ghalton.h"
+#include "sobol.h"
 
 
 static const R_CallMethodDef callMethods[] = {
 	{"korobov_", (DL_FUNC) &korobov_, 4},
 	{"ghalton_", (DL_FUNC) &ghalton_, 3},
+	{"sobol_",   (DL_FUNC) &sobol_, 3},
 	{NULL, NULL, 0}
 };
 
